import React, { useState, useRef, useEffect } from 'react';
import { Space, Table, Button, Image, Divider, Card, Input, Form } from 'antd';
import type { InputRef } from 'antd';
import type { ColumnType, ColumnsType } from 'antd/es/table';
import type { FilterConfirmProps, TableRowSelection } from 'antd/es/table/interface';
import { t } from '@/utils/i18n';
import { PlusOutlined, ExclamationCircleFilled, DeleteOutlined, SearchOutlined } from '@ant-design/icons';
import { antdUtils } from '@/utils/antd';
import { useRequest } from '@/hooks/use-request';
import type { DictTypeVO, DictDataVO, DictDataPageReqVO } from '@/models'
import dictDataService from '@/request/service/system-dictdata';

const { Search } = Input;

interface DictDataProps {
    data?: DictTypeVO | null;
}

export default (props: DictDataProps) => {

    const showDeleteConfirm = (item: DictDataVO) => {
        antdUtils.modal?.confirm({
            title: `确认删除值为: ${item.value} 的字典吗?`,
            icon: <ExclamationCircleFilled />,
            content: '请注意删除以后不可恢复！',
            okText: '删除',
            okType: 'danger',
            cancelText: '取消',
            onOk() {
                return new Promise(async (resolve) => {
                    const [error, { code, msg }] = await deleteDictDataApi(item.id);
                    if (error || code !== 0) {
                        antdUtils.message?.open({ type: 'error', content: msg ?? '操作失败' })
                    } else {
                        antdUtils.message?.open({ type: 'success', content: '删除成功' })
                    }
                    await load();
                    resolve('')
                }).catch(() => antdUtils.message?.open({
                    type: 'error',
                    content: '操作失败',
                }));
            },
            onCancel() {
            },
        });
    };

    const [editorVisable, seEditorVisable] = useState<boolean>(false);
    const [editData, seEditData] = useState<DictDataVO>();
    const [dataSource, setDataSource] = useState<DictDataVO[]>([]);
    const [total, setTotal] = useState(0);

    const { runAsync: getDictDataPageApi } = useRequest(dictDataService.getDictDataPageApi, { manual: true });
    const { runAsync: deleteDictDataApi } = useRequest(dictDataService.deleteDictDataApi, { manual: true });

    const load = async () => {
        const [error, { data }] = await getDictDataPageApi({
            dictType: props.data?.type,
            pageSize:10,
            pageNo:1
        });
        if (!error) {
            setDataSource(data.list);
            setTotal(data.total);
        }
    };


    const columns: ColumnsType<DictDataVO> = [
        {
            title: '数据标签',
            dataIndex: 'label',
            key: 'label',
            align: 'center',
            width: 150,
        },
        {
            title: '数据键值',
            dataIndex: 'value',
            key: 'value',
            align: 'center',
            width: 120,
        },

        {
            title: '状态',
            key: 'status',
            dataIndex: 'status',
            align: 'center',
            width: 120,
        },
        {
            title: t("QkOmYwne" /* 操作 */),
            key: 'action',
            align: 'center',
            render: (_, record) => (
                <Space size="middle" split={(
                    <Divider type='vertical' />
                )}>
                    <a
                        onClick={() => {
                            // setCreateVisible(true);
                            // setCurRowData(record);
                        }}>
                        编辑
                    </a>
                    <a
                        onClick={() => {
                            showDeleteConfirm(record)
                        }}>
                        删除
                    </a>
                </Space>
            ),
            width: 150,
        },
    ];

    useEffect(() => {
        load();
    }, [props]);

    return (
        <div>
            <div className="py-[8px] flex flex-row-reverse">
                <Button className="ml-5" type='primary' size='middle' icon={<PlusOutlined />}> 添加字典数据 </Button>
            </div>
            <Table rowKey="id"
                scroll={{ x: true }}
                columns={columns}
                dataSource={dataSource}
                className='bg-transparent'
                pagination={{
                    pageSize: 10,
                    current: 1,
                    total,
                    position: ['bottomRight']
                }}
            />
        </div>
    );
};
